crypto library

Underlying crypto primitives

Classes

Crc16
CRC16
Crc32c
CRC32C
KeyPair
({ Uint8List publicKey, Uint8List privateKey, })

Functions

openBox(Uint8List boxData, Uint8List key) → Uint8List
safeSign(Cell cell, Uint8List privateKey, [String seed = _defaultSeed]) → Uint8List
Returns a signature as Uint8List from the hash of cell and ceed and a privateKey
safeSignVerify(Cell cell, Uint8List signature, Uint8List publicKey, [String seed = _defaultSeed]) → bool
Returns true if hash from cell and seed confirms to the signature and publicKey, and false otherwise
sealBox(Uint8List data, Uint8List nonce, Uint8List key) → Uint8List
sign(Uint8List data, Uint8List privateKey) → Uint8List
signVerify(Uint8List data, Uint8List signature, Uint8List publicKey) → bool