WalletContractV4R2 class

IMPORTANT: Initialize the provider to use

Implemented types

Constructors

WalletContractV4R2(Uint8List publicKey, [int workChain = 0, int? walletId])

Properties

abi ↔ ContractABI?
getter/setter pairoverride
address ↔ InternalAddress
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
init ↔ ContractInit?
getter/setter pairoverride
provider ↔ ContractProvider?
getter/setter pairoverride
publicKey ↔ Uint8List
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
walletId ↔ int
getter/setter pair
workChain ↔ int
getter/setter pair

Methods

createSender(Uint8List privateKey) → dynamic
Returns a Sender
createTransfer({required int seqno, required Uint8List privateKey, required List<MessageRelaxed> messages, SendMode? sendMode, int? timeout}) → Cell
Returns a wallet transfer as a Cell
getBalance() → Future<BigInt>
Returns the balance of the wallet as a Future
getSeqno() → Future<int>
Returns the sequence number of the wallet as a Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(Cell message) → Future<void>
Returns nothing, sends a signed transfer
sendTransfer({required int seqno, required Uint8List privateKey, required List<MessageRelaxed> messages, SendMode? sendMode, int? timeout}) → Future<void>
Returns nothing, signs and sends the transfer
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create({required Uint8List publicKey, int workChain = 0, int? walletId}) → WalletContractV4R2
Returns a new instance of a WalletContractV4R2